@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Valve/trunk/lib/Data/Valve/Bucket.pm 65443 2008-07-10T02:19:14.430378Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Data-Valve/trunk/lib/Data/Valve/Bucket.pm 65475 2008-07-10T08:24:28.966073Z daisuke  $
 
 package Data::Valve::Bucket;
 use strict;
@@ -10,6 +10,11 @@ sub new {
     return $self;
 }
 
+sub deserialize {
+    my ($class, @args) = @_;
+    return bless _deserialize(@args), $class;
+}
+
 1;
 
 __END__
@@ -30,4 +35,18 @@ Data::Valve::Bucket - A Data Bucket
 
 =head2 destroy
 
+=head2 interval
+
+=head2 max_items
+
+=head2 count
+
+=head2 serialize
+
+=head2 deserialize
+
+=head2 first
+
+=head2 reset
+
 =cut
